/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_npdDePO3);
  numBytes += sPhasor_k_init(&sPhasor_UEbCxO1p, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_RpJyJsWE);
  numBytes += sRPole_init(&sRPole_HGCz9Pe8);
  numBytes += sRPole_init(&sRPole_4b5tzTMm);
  numBytes += sTabhead_init(&sTabhead_naVJjpwm, &hTable_kIew5ny7);
  numBytes += sTabread_init(&sTabread_9R9d5KOR, &hTable_kIew5ny7, false);
  numBytes += sTabread_init(&sTabread_dDdYFVSm, &hTable_kIew5ny7, false);
  numBytes += sLine_init(&sLine_HFPCXPtc);
  numBytes += sTabhead_init(&sTabhead_yivCz0qz, &hTable_TreYB8b1);
  numBytes += sTabread_init(&sTabread_ppiwaA9Z, &hTable_TreYB8b1, false);
  numBytes += sTabread_init(&sTabread_GN9FP0Bl, &hTable_TreYB8b1, false);
  numBytes += sLine_init(&sLine_fK9gnl2M);
  numBytes += sTabwrite_init(&sTabwrite_D44U8Nle, &hTable_TreYB8b1);
  numBytes += sTabwrite_init(&sTabwrite_m1jDN5zl, &hTable_kIew5ny7);
  numBytes += cVar_init_f(&cVar_Iu08Rm3v, 0.0f);
  numBytes += cVar_init_f(&cVar_XNR24PwS, 0.0f);
  numBytes += cVar_init_f(&cVar_5uO4dkRr, 0.0f);
  numBytes += cVar_init_f(&cVar_qXHleugh, 0.0f);
  numBytes += cVar_init_s(&cVar_2co27koc, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_bxbsukiD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2yD77AgV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lR3FPbmW, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Df7SlhvD, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_WyBc4nKF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T9ny3vkx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QnmXjfv8, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_EnlC8ZII, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gCMzKEIu, 0.0f);
  numBytes += hTable_init(&hTable_TreYB8b1, 256);
  numBytes += cDelay_init(this, &cDelay_oBrE1iUF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hpt2TKSh, 0.0f);
  numBytes += hTable_init(&hTable_kIew5ny7, 256);
  numBytes += cVar_init_f(&cVar_KvTc4OhU, 14.0f);
  numBytes += cBinop_init(&cBinop_F40RAgeq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9DL5igHF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lAY0hwfH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3sU4qdUv, 14.0f);
  numBytes += cBinop_init(&cBinop_1AcLwaZL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fziPTsVe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mcvEVHbx, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_5Uqj10c1, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_Ud5zocOu, 1, -1);
  numBytes += cVar_init_f(&cVar_3uMBR3Gu, 0.2f);
  numBytes += cSlice_init(&cSlice_TIYcolX3, 1, -1);
  numBytes += cVar_init_f(&cVar_3cyNC0Lm, 0.0f);
  numBytes += cSlice_init(&cSlice_E359Q1rX, 1, -1);
  numBytes += cVar_init_f(&cVar_8jbz86TP, 2.0f);
  numBytes += cSlice_init(&cSlice_Me0Elfla, 1, -1);
  numBytes += cVar_init_f(&cVar_DcbXahSb, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_TreYB8b1);
  hTable_free(&hTable_kIew5ny7);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_TreYB8b1; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_kIew5ny7; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qPs2USqO_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qNwIrsvF_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W4vhOG0v_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NoreR9QY_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kx8zU270_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZUtWuwYL_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AS4wv3tq_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wEmpbPWr_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D1XnGsQ6_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_Iu08Rm3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oW3rjl6g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_XNR24PwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hzfXoiaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_5uO4dkRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OpMuba86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_qXHleugh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JNB9As2P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Zxno6BQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rQyto7LT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rQyto7LT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_UEbCxO1p, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_94te7uNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_keafTtPo_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_keafTtPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FwwFNSIq_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_2co27koc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2IbGTQpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_G599ZCMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0zMsXqIe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bxbsukiD, m);
}

void Heavy_WSTD_FLANGR::cBinop_FwwFNSIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2yD77AgV, m);
}

void Heavy_WSTD_FLANGR::cMsg_2IbGTQpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G599ZCMi_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_0zMsXqIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lR3FPbmW, m);
}

void Heavy_WSTD_FLANGR::cMsg_b2IXZ0tK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zXhFTTgV_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_zXhFTTgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1A2IRGuU_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_Df7SlhvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L5eJ4gSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_emqOvI5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VWV9pDkz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WyBc4nKF, m);
}

void Heavy_WSTD_FLANGR::cBinop_1A2IRGuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_T9ny3vkx, m);
}

void Heavy_WSTD_FLANGR::cMsg_L5eJ4gSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_emqOvI5q_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_VWV9pDkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QnmXjfv8, m);
}

void Heavy_WSTD_FLANGR::cBinop_l2a2N8ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LT2KuRVT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_LT2KuRVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_HseBLTp6_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_54ojeAPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T3QeQ6nN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_qReI2QR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2BSZNNUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_HseBLTp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vYGdeu04_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_vYGdeu04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yCIU6JdB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mEem9kEj_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_mEem9kEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7vyy2oc6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_yCIU6JdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rgUh0ato_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rgUh0ato_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5vNZHO0F_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_7vyy2oc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lo8gjdBI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lo8gjdBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5hACNDrK_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5vNZHO0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_54ojeAPm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5hACNDrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qReI2QR5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_t0ppDFle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_phuJ8Ddr_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_phuJ8Ddr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_njUMzwBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_6DgHqWr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FTRamRLk_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_FTRamRLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lp9IkH5U_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_EnlC8ZII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EnlC8ZII, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gCMzKEIu, 0, m, &cDelay_gCMzKEIu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EnlC8ZII, 0, m, &cDelay_EnlC8ZII_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_D44U8Nle, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_gCMzKEIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gCMzKEIu, m);
  cMsg_gajoF926_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_mjhzPhgq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_E0UUxMap_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_DaU2iouz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vTsN4ID6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_TreYB8b1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mMo9YIEK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EnlC8ZII, 2, m, &cDelay_EnlC8ZII_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZYluyjLa_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_vTsN4ID6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TreYB8b1, 0, m, &hTable_TreYB8b1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lp9IkH5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_DaU2iouz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_gajoF926_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TreYB8b1, 0, m, &hTable_TreYB8b1_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_ZYluyjLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EnlC8ZII, 0, m, &cDelay_EnlC8ZII_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_mMo9YIEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gCMzKEIu, 2, m, &cDelay_gCMzKEIu_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_E0UUxMap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_D44U8Nle, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_WZ8u0xet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ANIvb7WA_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_ANIvb7WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ehR43HtN_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_oBrE1iUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oBrE1iUF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hpt2TKSh, 0, m, &cDelay_hpt2TKSh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oBrE1iUF, 0, m, &cDelay_oBrE1iUF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_m1jDN5zl, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_hpt2TKSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hpt2TKSh, m);
  cMsg_zWabtu86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_1ikA51SV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bEbV7e1P_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_4CYyOBV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2xCVusrr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_kIew5ny7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qx4or86F_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oBrE1iUF, 2, m, &cDelay_oBrE1iUF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aSxWK6T8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_2xCVusrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kIew5ny7, 0, m, &hTable_kIew5ny7_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ehR43HtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_4CYyOBV2_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_zWabtu86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kIew5ny7, 0, m, &hTable_kIew5ny7_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_aSxWK6T8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oBrE1iUF, 0, m, &cDelay_oBrE1iUF_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_qx4or86F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hpt2TKSh, 2, m, &cDelay_hpt2TKSh_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_bEbV7e1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_m1jDN5zl, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_KvTc4OhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F40RAgeq, HV_BINOP_MULTIPLY, 0, m, &cBinop_F40RAgeq_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ZaNQK2KH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2IFTjxEB_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_2IFTjxEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AeXKm9xE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_F40RAgeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9Nzlhaed_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Xj9wiGA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F40RAgeq, HV_BINOP_MULTIPLY, 1, m, &cBinop_F40RAgeq_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_AeXKm9xE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Xj9wiGA3_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9Nzlhaed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7Ep63jbm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7Ep63jbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nIfeKj7n_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lAY0hwfH, m);
}

void Heavy_WSTD_FLANGR::cBinop_nIfeKj7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9DL5igHF, m);
}

void Heavy_WSTD_FLANGR::cVar_3sU4qdUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1AcLwaZL, HV_BINOP_MULTIPLY, 0, m, &cBinop_1AcLwaZL_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_HUJigkPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pNc1GeOY_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_pNc1GeOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fz8VGFJR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_1AcLwaZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9TzbkBnz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_NkN9P9sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1AcLwaZL, HV_BINOP_MULTIPLY, 1, m, &cBinop_1AcLwaZL_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_fz8VGFJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NkN9P9sm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9TzbkBnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9ZkBoIIx_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9ZkBoIIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ybTDkFFr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mcvEVHbx, m);
}

void Heavy_WSTD_FLANGR::cBinop_ybTDkFFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fziPTsVe, m);
}

void Heavy_WSTD_FLANGR::cMsg_njUMzwBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RpJyJsWE, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_qHS05oDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_fRiqWceq_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_1C0wipCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_qHS05oDX_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_2XLqBREz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UHLEzVc8_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_AABACEA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qi8jR0l6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_qi8jR0l6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Uqj10c1, HV_BINOP_MULTIPLY, 1, m, &cBinop_5Uqj10c1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_UHLEzVc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AABACEA4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5Uqj10c1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGJQaXCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_fRiqWceq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Uqj10c1, HV_BINOP_MULTIPLY, 0, m, &cBinop_5Uqj10c1_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_WGJQaXCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fK9gnl2M, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_yemBhEVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_KWeoYoE6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_KWeoYoE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2XLqBREz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1C0wipCJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_jV4eyaT3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ud5zocOu, 0, m, &cSlice_Ud5zocOu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IKqarBR3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Ud5zocOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VsuepvN8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VsuepvN8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_3uMBR3Gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VsuepvN8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_VsuepvN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZUtWuwYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_IKqarBR3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TIYcolX3, 0, m, &cSlice_TIYcolX3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2biU1D1f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_TIYcolX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_umLZIRLS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_umLZIRLS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_3cyNC0Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_umLZIRLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_umLZIRLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kx8zU270_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_2biU1D1f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E359Q1rX, 0, m, &cSlice_E359Q1rX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zQyhPHSU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_E359Q1rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z7WL0O6l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z7WL0O6l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_8jbz86TP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z7WL0O6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_z7WL0O6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wEmpbPWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_zQyhPHSU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Me0Elfla, 0, m, &cSlice_Me0Elfla_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Me0Elfla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ShJSFGst_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ShJSFGst_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_DcbXahSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ShJSFGst_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ShJSFGst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AS4wv3tq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_T3QeQ6nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HFPCXPtc, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_2BSZNNUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_npdDePO3, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_JNB9As2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jV4eyaT3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_oW3rjl6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jV4eyaT3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_hzfXoiaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jV4eyaT3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_OpMuba86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jV4eyaT3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_81gYn4Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qXHleugh, 0, m, &cVar_qXHleugh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_gyFh0oTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iu08Rm3v, 0, m, &cVar_Iu08Rm3v_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_sy7olsLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5uO4dkRr, 0, m, &cVar_5uO4dkRr_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_wEmpbPWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_Zxno6BQE_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_kx8zU270_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yemBhEVS_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_D1XnGsQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZaNQK2KH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KvTc4OhU, 0, m, &cVar_KvTc4OhU_sendMessage);
  cMsg_HUJigkPy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3sU4qdUv, 0, m, &cVar_3sU4qdUv_sendMessage);
  cMsg_6DgHqWr8_sendMessage(_c, 0, m);
  cMsg_WZ8u0xet_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3uMBR3Gu, 0, m, &cVar_3uMBR3Gu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3cyNC0Lm, 0, m, &cVar_3cyNC0Lm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8jbz86TP, 0, m, &cVar_8jbz86TP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DcbXahSb, 0, m, &cVar_DcbXahSb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2co27koc, 0, m, &cVar_2co27koc_sendMessage);
  cMsg_94te7uNa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Df7SlhvD, 0, m, &cVar_Df7SlhvD_sendMessage);
  cMsg_b2IXZ0tK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_AS4wv3tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_l2a2N8ub_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_ZUtWuwYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_t0ppDFle_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_NoreR9QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XNR24PwS, 0, m, &cVar_XNR24PwS_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_W4vhOG0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_81gYn4Jt_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qNwIrsvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_sy7olsLc_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qPs2USqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gyFh0oTr_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_npdDePO3, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_UEbCxO1p, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_RpJyJsWE, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_lAY0hwfH, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_9DL5igHF, VOf(Bf3));
    __hv_rpole_f(&sRPole_HGCz9Pe8, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mcvEVHbx, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_fziPTsVe, VOf(Bf4));
    __hv_rpole_f(&sRPole_4b5tzTMm, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_naVJjpwm, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_2yD77AgV, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_lR3FPbmW, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_bxbsukiD, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_9R9d5KOR, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_dDdYFVSm, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_HFPCXPtc, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_yivCz0qz, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_T9ny3vkx, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_QnmXjfv8, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_WyBc4nKF, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ppiwaA9Z, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_GN9FP0Bl, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_fK9gnl2M, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_D44U8Nle, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_m1jDN5zl, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
