/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalRPole.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvSignalTabwrite.h"
#include "HvSignalPhasor.h"
#include "HvMath.h"
#include "HvSignalTabread.h"
#include "HvTable.h"
#include "HvSignalDel1.h"
#include "HvControlUnop.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_Iu08Rm3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XNR24PwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5uO4dkRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qXHleugh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zxno6BQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQyto7LT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_94te7uNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_keafTtPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2co27koc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_G599ZCMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FwwFNSIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2IbGTQpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0zMsXqIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b2IXZ0tK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zXhFTTgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Df7SlhvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_emqOvI5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1A2IRGuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L5eJ4gSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VWV9pDkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l2a2N8ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LT2KuRVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_54ojeAPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qReI2QR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HseBLTp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vYGdeu04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mEem9kEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yCIU6JdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgUh0ato_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7vyy2oc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lo8gjdBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5vNZHO0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5hACNDrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t0ppDFle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_phuJ8Ddr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6DgHqWr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FTRamRLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EnlC8ZII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gCMzKEIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mjhzPhgq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_DaU2iouz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TreYB8b1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vTsN4ID6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lp9IkH5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gajoF926_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZYluyjLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mMo9YIEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E0UUxMap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WZ8u0xet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ANIvb7WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oBrE1iUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hpt2TKSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1ikA51SV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_4CYyOBV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_kIew5ny7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2xCVusrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ehR43HtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zWabtu86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aSxWK6T8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qx4or86F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bEbV7e1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KvTc4OhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZaNQK2KH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2IFTjxEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F40RAgeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xj9wiGA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AeXKm9xE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Nzlhaed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Ep63jbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nIfeKj7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3sU4qdUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HUJigkPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pNc1GeOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1AcLwaZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NkN9P9sm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fz8VGFJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9TzbkBnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ZkBoIIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ybTDkFFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_njUMzwBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qHS05oDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1C0wipCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2XLqBREz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AABACEA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qi8jR0l6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UHLEzVc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Uqj10c1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fRiqWceq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WGJQaXCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yemBhEVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWeoYoE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jV4eyaT3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Ud5zocOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3uMBR3Gu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VsuepvN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IKqarBR3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TIYcolX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3cyNC0Lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_umLZIRLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2biU1D1f_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_E359Q1rX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8jbz86TP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z7WL0O6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zQyhPHSU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Me0Elfla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DcbXahSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ShJSFGst_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T3QeQ6nN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2BSZNNUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JNB9As2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oW3rjl6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hzfXoiaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OpMuba86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_81gYn4Jt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gyFh0oTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sy7olsLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wEmpbPWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kx8zU270_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_D1XnGsQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AS4wv3tq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZUtWuwYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NoreR9QY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_W4vhOG0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qNwIrsvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qPs2USqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_npdDePO3;
  SignalPhasor sPhasor_UEbCxO1p;
  SignalLine sLine_RpJyJsWE;
  SignalRPole sRPole_HGCz9Pe8;
  SignalRPole sRPole_4b5tzTMm;
  SignalTabhead sTabhead_naVJjpwm;
  SignalTabread sTabread_9R9d5KOR;
  SignalTabread sTabread_dDdYFVSm;
  SignalLine sLine_HFPCXPtc;
  SignalTabhead sTabhead_yivCz0qz;
  SignalTabread sTabread_ppiwaA9Z;
  SignalTabread sTabread_GN9FP0Bl;
  SignalLine sLine_fK9gnl2M;
  SignalTabwrite sTabwrite_D44U8Nle;
  SignalTabwrite sTabwrite_m1jDN5zl;
  ControlVar cVar_Iu08Rm3v;
  ControlVar cVar_XNR24PwS;
  ControlVar cVar_5uO4dkRr;
  ControlVar cVar_qXHleugh;
  ControlBinop cBinop_Zxno6BQE;
  ControlBinop cBinop_rQyto7LT;
  ControlVar cVar_2co27koc;
  ControlBinop cBinop_FwwFNSIq;
  ControlBinop cBinop_0zMsXqIe;
  SignalVarf sVarf_bxbsukiD;
  SignalVarf sVarf_2yD77AgV;
  SignalVarf sVarf_lR3FPbmW;
  ControlVar cVar_Df7SlhvD;
  ControlBinop cBinop_1A2IRGuU;
  ControlBinop cBinop_VWV9pDkz;
  SignalVarf sVarf_WyBc4nKF;
  SignalVarf sVarf_T9ny3vkx;
  SignalVarf sVarf_QnmXjfv8;
  ControlBinop cBinop_l2a2N8ub;
  ControlBinop cBinop_LT2KuRVT;
  ControlBinop cBinop_HseBLTp6;
  ControlBinop cBinop_vYGdeu04;
  ControlBinop cBinop_rgUh0ato;
  ControlBinop cBinop_lo8gjdBI;
  ControlBinop cBinop_5vNZHO0F;
  ControlBinop cBinop_5hACNDrK;
  ControlBinop cBinop_t0ppDFle;
  ControlBinop cBinop_phuJ8Ddr;
  ControlDelay cDelay_EnlC8ZII;
  ControlDelay cDelay_gCMzKEIu;
  ControlBinop cBinop_DaU2iouz;
  HvTable hTable_TreYB8b1;
  ControlBinop cBinop_lp9IkH5U;
  ControlDelay cDelay_oBrE1iUF;
  ControlDelay cDelay_hpt2TKSh;
  ControlBinop cBinop_4CYyOBV2;
  HvTable hTable_kIew5ny7;
  ControlBinop cBinop_ehR43HtN;
  ControlVar cVar_KvTc4OhU;
  ControlBinop cBinop_F40RAgeq;
  ControlBinop cBinop_Xj9wiGA3;
  SignalVarf sVarf_9DL5igHF;
  ControlBinop cBinop_9Nzlhaed;
  ControlBinop cBinop_7Ep63jbm;
  ControlBinop cBinop_nIfeKj7n;
  SignalVarf sVarf_lAY0hwfH;
  ControlVar cVar_3sU4qdUv;
  ControlBinop cBinop_1AcLwaZL;
  ControlBinop cBinop_NkN9P9sm;
  SignalVarf sVarf_fziPTsVe;
  ControlBinop cBinop_9TzbkBnz;
  ControlBinop cBinop_9ZkBoIIx;
  ControlBinop cBinop_ybTDkFFr;
  SignalVarf sVarf_mcvEVHbx;
  ControlBinop cBinop_AABACEA4;
  ControlBinop cBinop_qi8jR0l6;
  ControlBinop cBinop_UHLEzVc8;
  ControlBinop cBinop_5Uqj10c1;
  ControlBinop cBinop_fRiqWceq;
  ControlBinop cBinop_yemBhEVS;
  ControlBinop cBinop_KWeoYoE6;
  ControlSlice cSlice_Ud5zocOu;
  ControlVar cVar_3uMBR3Gu;
  ControlSlice cSlice_TIYcolX3;
  ControlVar cVar_3cyNC0Lm;
  ControlSlice cSlice_E359Q1rX;
  ControlVar cVar_8jbz86TP;
  ControlSlice cSlice_Me0Elfla;
  ControlVar cVar_DcbXahSb;
  ControlBinop cBinop_81gYn4Jt;
  ControlBinop cBinop_gyFh0oTr;
  ControlBinop cBinop_sy7olsLc;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
